@@ -1,4 +1,4 @@
-/* $Id: directory-handle.h,v 1.8 2005/04/15 10:56:16 murrayc Exp $ */
+/* $Id: directory-handle.h,v 1.9 2006/10/31 09:06:42 murrayc Exp $ */
 
 /* Copyright 2003 gnome-vfsmm Development Team
  *
@@ -58,6 +58,7 @@ public:
 						  gboolean *recurse);
   */
               
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   static void visit(const Glib::ustring& uri, FileInfoOptions info_options, DirectoryVisitOptions visit_options, const SlotVisit& slot) throw(exception);
   static void visit(const Glib::RefPtr<const Uri>& uri, FileInfoOptions info_options, DirectoryVisitOptions visit_options, const SlotVisit& slot) throw(exception);
  
@@ -76,6 +77,26 @@ public:
   /** @result If the file does not exist then this will be false.
    */
   Glib::RefPtr<FileInfo> read_next() throw(exception);
+#else
+  static void visit(const Glib::ustring& uri, FileInfoOptions info_options, DirectoryVisitOptions visit_options, const SlotVisit& slot, std::auto_ptr<Gnome::Vfs::exception>& error);
+  static void visit(const Glib::RefPtr<const Uri>& uri, FileInfoOptions info_options, DirectoryVisitOptions visit_options, const SlotVisit& slot, std::auto_ptr<Gnome::Vfs::exception>& error);
+ 
+  static void visit_files(const Glib::ustring& uri, const Glib::ListHandle<Glib::ustring>& file_list, FileInfoOptions info_options, DirectoryVisitOptions visit_options, const SlotVisit& slot, std::auto_ptr<Gnome::Vfs::exception>& error);
+  static void visit_files(const Glib::RefPtr<const Uri>& uri, const Glib::ListHandle<Glib::ustring> & file_list, FileInfoOptions info_options, DirectoryVisitOptions visit_options, const SlotVisit& slot, std::auto_ptr<Gnome::Vfs::exception>& error);
+
+  static void list_load(const Glib::ListHandle<Glib::ustring>& list, const Glib::ustring& text_uri, FileInfoOptions info_options, std::auto_ptr<Gnome::Vfs::exception>& error);
+
+  void open(const Glib::ustring& text_uri, FileInfoOptions options, std::auto_ptr<Gnome::Vfs::exception>& error);
+  void open(const Glib::RefPtr<const Uri>& uri, FileInfoOptions options, std::auto_ptr<Gnome::Vfs::exception>& error);
+
+  void close(std::auto_ptr<Gnome::Vfs::exception>& error);
+
+  Glib::RefPtr<FileInfo> read_next(bool& file_exists, std::auto_ptr<Gnome::Vfs::exception>& error);
+
+  /** @result If the file does not exist then this will be false.
+   */
+  Glib::RefPtr<FileInfo> read_next(std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
   
   GnomeVFSDirectoryHandle* gobj();
   const GnomeVFSDirectoryHandle* gobj() const;  
