@@ -26,6 +26,15 @@
 #include <libgnomevfsmm/mime-application.h>
 #include <libgnomevfsmm/mime-action.h>
 
+/* 
+ * If the underlying GConf implementation does not use Orbit, then
+ * stub out the return of functions which are Bonobo-specific
+ */
+#include <libgnomevfs/gnome-vfs-mime-handlers.h>
+#ifdef DISABLE_ORBIT
+typedef void Bonobo_ServerInfo;
+#endif
+
 namespace Gnome
 {
 
@@ -186,19 +195,31 @@ ListHandleStrings get_key_list(Glib::ustring& mime_type);
  * @param mime_type A string containing an MIME type.
  * @param action_type An enum specifying the default action to perform.
  */ 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void set_default_action_type(const Glib::ustring& mime_type, MimeActionType action_type) throw(exception);
+#else
+void set_default_action_type(const Glib::ustring& mime_type, MimeActionType action_type, std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 /** Sets the default application to run on files of the specified MIME type.
  * @param mime_type A string containing an MIME type.
  * @param application_id A string containing an ID of an application in the MIME database.
  */
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void set_default_application(const Glib::ustring& mime_type, const Glib::ustring& application_id) throw(exception);
+#else
+void set_default_application(const Glib::ustring& mime_type, const Glib::ustring& application_id, std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 /** Sets the default component to use with files of the specified MIME type.
  * @param mime_type A string containing an MIME type.
  * @param iid A string containing an OAF IID of a component in the MIME database.
  */
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void set_default_component(const Glib::ustring& mime_type, const Glib::ustring& iid) throw(exception);
+#else
+void set_default_component(const Glib::ustring& mime_type, const Glib::ustring& iid, std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 /** Set the icon entry for a particular MIME type in the MIME database.
  * Note that icon entries need not necessarily contain the full path, and do not necessarily need to
@@ -207,93 +228,149 @@ void set_default_component(const Glib::ustring& mime_type, const Glib::ustring&
  * @param mime_type A string containing an MIME type.
  * @param filename A string containing an image filename.
  */
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void set_icon(const Glib::ustring& mime_type, const Glib::ustring& filename) throw(exception);
+#else
+void set_icon(const Glib::ustring& mime_type, const Glib::ustring& filename, std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 /** Set the description of this MIME type in the MIME database.
  * The description should be something like &quot;Gnumeric spreadsheet&quot;.
  * @param mime_type A string containing an MIME type.
  * @param description A description of this MIME type.
  */
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void set_description(const Glib::ustring& mime_type, const Glib::ustring& description) throw(exception);
+#else
+void set_description(const Glib::ustring& mime_type, const Glib::ustring& description, std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 /** Set whether files of this MIME type might conceivably be executable.
  * @param mime_type A string containing an MIME type.
  * @param new_value A boolean value indicating whether @a mime_type could be executable.
  */
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void set_can_be_executable(const Glib::ustring& mime_type, bool new_value) throw(exception);
+#else
+void set_can_be_executable(const Glib::ustring& mime_type, bool new_value, std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 /** Set the short list of applications for the specified MIME type.
  * The short list contains applications recommended for possible selection by the user.
  * @param mime_type A string containing an MIME type.
  * @param application_ids A list of application IDs.
  */
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void set_short_list_applications(const Glib::ustring& mime_type, ListHandleStrings& application_ids) throw(exception);
+#else
+void set_short_list_applications(const Glib::ustring& mime_type, ListHandleStrings& application_ids, std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 /** Set the short list of components for the specified MIME type.
  * The short list contains components recommended for possible selection by the user.
  * @param mime_type A string containing an MIME type.
  * @param component_iids A list of OAF IID's.
  */
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void set_short_list_components(const Glib::ustring& mime_type, ListHandleStrings& component_iids) throw(exception);
+#else
+void set_short_list_components(const Glib::ustring& mime_type, ListHandleStrings& component_iids, std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 /** Add an application to the short list for the specified MIME type.
  * The short list contains applications recommended for possible selection by the user.
  * @param mime_type A string containing an MIME type.
  * @param application_id A string containing the application's ID in the MIME database.
  */
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void add_application_to_short_list(const Glib::ustring& mime_type, Glib::ustring& application_id) throw(exception);
+#else
+void add_application_to_short_list(const Glib::ustring& mime_type, Glib::ustring& application_id, std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 /** Remove an application from the short list for the specified MIME type.
  * The short list contains applications recommended for possible selection by the user.
  * @param mime_type A string containing an MIME type.
  * @param application_id A string containing the application's ID in the MIME database.
  */
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void remove_application_from_short_list(const Glib::ustring& mime_type, Glib::ustring& application_id) throw(exception);
+#else
+void remove_application_from_short_list(const Glib::ustring& mime_type, Glib::ustring& application_id, std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 /** Add a component to the short list for the specified MIME type.
  * The short list contains components recommended for possible selection by the user.
  * @param mime_type A string containing an MIME type.
  * @param component_iid A string containing the component's OAF IID in the MIME database.
  */
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void add_component_to_short_list(const Glib::ustring& mime_type, Glib::ustring& component_iid) throw(exception);
+#else
+void add_component_to_short_list(const Glib::ustring& mime_type, Glib::ustring& component_iid, std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 /** Remove a component from the short list for the specified MIME type.
  * The short list contains components recommended for possible selection by the user.
  * @param mime_type A string containing an MIME type.
  * @param component_iid A string containing the component's OAF IID in the MIME database.
  */
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void remove_component_from_short_list(const Glib::ustring& mime_type, Glib::ustring& component_iid) throw(exception);
+#else
+void remove_component_from_short_list(const Glib::ustring& mime_type, Glib::ustring& component_iid, std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 /** Add a file extension to the specified MIME type in the database.
  * @param mime_type The mime type to add the extension to.
  * @param extension The extension to add.
  */
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void add_extension(const Glib::ustring& mime_type, Glib::ustring& extension) throw(exception);
+#else
+void add_extension(const Glib::ustring& mime_type, Glib::ustring& extension, std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 /** Removes a file extension from the specified MIME type in the database.
  * @param mime_type The mime type to remove the extension from.
  * @param extension The extension to remove.
  */
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void remove_extension(const Glib::ustring& mime_type, Glib::ustring& extension) throw(exception);
+#else
+void remove_extension(const Glib::ustring& mime_type, Glib::ustring& extension, std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 /** Sets the extensions for a given mime type.
  * Overrides the previously set extensions.
  * @param mime_type A string containing an MIME type.
  * @param extensions_list A whitespace-separated list of the extensions to set for this MIME type.
  */
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void set_extensions_list(const Glib::ustring& mime_type, const Glib::ustring& extensions_list) throw(exception);
+#else
+void set_extensions_list(const Glib::ustring& mime_type, const Glib::ustring& extensions_list, std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 /** Register @a mime_type as being handled by all applications listed in @a application_ids.
  * @param mime_type A string containing an MIME type.
  * @param application_ids A list of strings containing application ids.
  */
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void extend_all_applications(const Glib::ustring& mime_type, ListHandleStrings& application_ids) throw(exception);
+#else
+void extend_all_applications(const Glib::ustring& mime_type, ListHandleStrings& application_ids, std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 /** Remove @a mime_type as a handled type from every application in @a application_ids.
  * @param mime_type A string containing an MIME type.
  * @param application_ids A list of strings containing application ids.
  */
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void remove_from_all_applications(const Glib::ustring& mime_type, ListHandleStrings& application_ids) throw(exception);
+#else
+void remove_from_all_applications(const Glib::ustring& mime_type, ListHandleStrings& application_ids, std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 /** Delete an MIME type for the user who runs this command.
  * You can only undo this by calling Gnome::Vfs::Mime::reset().
@@ -306,7 +383,11 @@ void registered_mime_type_delete(const Glib::ustring& mime_type);
  * @param key A string containing the key to set.
  * @param data A string containing the data to set for @a key.
  */
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void set_registered_type_key(const Glib::ustring& mime_type, const Glib::ustring& key, const Glib::ustring& data) throw(exception);
+#else
+void set_registered_type_key(const Glib::ustring& mime_type, const Glib::ustring& key, const Glib::ustring& data, std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 /** Set the value associated with the key.
  * Will save it to the user's file if necessary.
@@ -314,7 +395,11 @@ void set_registered_type_key(const Glib::ustring& mime_type, const Glib::ustring
  * @param key A string containing the key to store the value in.
  * @param value A string containing the value to stor in the key.
  */
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void set_value(const Glib::ustring& mime_type, const Glib::ustring& key, const Glib::ustring& value) throw(exception);
+#else
+void set_value(const Glib::ustring& mime_type, const Glib::ustring& key, const Glib::ustring& value, std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 /*
  * Mime Control
